@@ -10,9 +10,9 @@
  */
 
 
-#ifndef mir_api_MIRComplexJob_h
-#define mir_api_MIRComplexJob_h
+#pragma once
 
+#include <iosfwd>
 #include <vector>
 
 
@@ -43,10 +43,12 @@ public:
     // -- Exceptions
     // None
 
-    // -- Contructors
+    // -- Constructors
 
     MIRComplexJob();
+
     MIRComplexJob(const MIRComplexJob&) = delete;
+    MIRComplexJob(MIRComplexJob&&)      = delete;
 
     // -- Destructor
 
@@ -56,7 +58,9 @@ public:
     // None
 
     // -- Operators
+
     void operator=(const MIRComplexJob&) = delete;
+    void operator=(MIRComplexJob&&)      = delete;
 
     // -- Methods
 
@@ -123,6 +127,3 @@ private:
 
 }  // namespace api
 }  // namespace mir
-
-
-#endif
