@@ -13,22 +13,21 @@
 #include "mir/repres/unsupported/IrregularLatlon.h"
 
 #include <cmath>
-#include <iostream>
+#include <ostream>
 
 #include "eckit/utils/MD5.h"
 
-#include "mir/api/Atlas.h"
-#include "mir/config/LibMir.h"
+#include "mir/api/mir_config.h"
 #include "mir/param/MIRParametrisation.h"
 #include "mir/repres/Iterator.h"
-#include "mir/util/Assert.h"
 #include "mir/util/Domain.h"
+#include "mir/util/Exceptions.h"
+#include "mir/util/Log.h"
 #include "mir/util/MeshGeneratorParameters.h"
-#include "mir/util/Pretty.h"
+#include "mir/util/Types.h"
 
 
-namespace mir {
-namespace repres {
+namespace mir::repres::unsupported {
 
 
 static void range(const std::vector<double>& v, double& mn, double& mx, double& dmax) {
@@ -86,11 +85,11 @@ bool IrregularLatlon::getLongestElementDiagonal(double& d) const {
     d = 0.;
     for (size_t j = 1; j < latitudes_.size(); ++j) {
         const bool away(std::abs(latitudes_[j - 1]) > std::abs(latitudes_[j]));
-        auto& latAwayFromEquator(latitudes_[away ? j - 1 : j]);
-        auto& latCloserToEquator(latitudes_[away ? j : j - 1]);
+        const auto& latAwayFromEquator(latitudes_[away ? j - 1 : j]);
+        const auto& latCloserToEquator(latitudes_[away ? j : j - 1]);
 
-        d = std::max(d, atlas::util::Earth::distance(atlas::PointLonLat(0., latCloserToEquator),
-                                                     atlas::PointLonLat(we, latAwayFromEquator)));
+        d = std::max(d, util::Earth::distance(atlas::PointLonLat(0., latCloserToEquator),
+                                              atlas::PointLonLat(we, latAwayFromEquator)));
     }
 
     ASSERT(d > 0.);
@@ -101,8 +100,8 @@ bool IrregularLatlon::getLongestElementDiagonal(double& d) const {
 void IrregularLatlon::validate(const MIRValuesVector& values) const {
     const size_t count = numberOfPoints();
 
-    eckit::Log::debug<LibMir>() << "IrregularLatlon::validate checked " << Pretty(values.size(), {"value"})
-                                << ", iterator counts " << Pretty(count) << " (" << domain() << ")." << std::endl;
+    Log::debug() << "IrregularLatlon::validate checked " << Log::Pretty(values.size(), {"value"})
+                 << ", iterator counts " << Log::Pretty(count) << " (" << domain() << ")." << std::endl;
 
     ASSERT_VALUES_SIZE_EQ_ITERATOR_COUNT("IrregularLatlon", values.size(), count);
 }
@@ -127,17 +126,17 @@ void IrregularLatlon::makeName(std::ostream& out) const {
 
 
 bool IrregularLatlon::sameAs(const Representation& other) const {
-    auto o = dynamic_cast<const IrregularLatlon*>(&other);
+    const auto* o = dynamic_cast<const IrregularLatlon*>(&other);
     return (o != nullptr) && (latitudes_ == o->latitudes_) && (longitudes_ == o->longitudes_);
 }
 
 
-void IrregularLatlon::fill(grib_info&) const {
+void IrregularLatlon::fillGrib(grib_info& /*unused*/) const {
     NOTIMP;
 }
 
 
-void IrregularLatlon::fill(util::MeshGeneratorParameters& params) const {
+void IrregularLatlon::fillMeshGen(util::MeshGeneratorParameters& params) const {
     if (params.meshGenerator_.empty()) {
         params.meshGenerator_ = "delaunay";
     }
@@ -155,51 +154,70 @@ util::Domain IrregularLatlon::domain() const {
 
 
 class IrregularLatlonIterator : public Iterator {
-    size_t count_;
     size_t i_;
     size_t ni_;
     size_t j_;
     size_t nj_;
+    size_t count_;
+    bool first_;
 
     const std::vector<double>& latitudes_;
     const std::vector<double>& longitudes_;
 
-    virtual void print(std::ostream& out) const {
+    void print(std::ostream& out) const override {
         out << "IrregularLatlonIterator[";
         Iterator::print(out);
         out << "]";
     }
 
-    virtual bool next(Latitude& lat, Longitude& lon) {
+    bool next(Latitude& lat, Longitude& lon) override {
         if (j_ < nj_) {
             if (i_ < ni_) {
                 lat = latitudes_[j_];
                 lon = longitudes_[i_];
-                i_++;
-                if (i_ == ni_) {
-                    j_++;
+
+                if (first_) {
+                    first_ = false;
+                }
+                else {
+                    count_++;
+                }
+
+                if (++i_ == ni_) {
+                    ++j_;
                     i_ = 0;
                 }
-                count_++;
+
                 return true;
             }
         }
         return false;
     }
 
+    size_t index() const override { return count_; }
+
 public:
     // TODO: Consider keeping a reference on the latitudes and bbox, to avoid copying
 
     IrregularLatlonIterator(const std::vector<double>& latitudes, const std::vector<double>& longitudes) :
-        count_(0),
         i_(0),
         ni_(longitudes.size()),
         j_(0),
         nj_(latitudes.size()),
+        count_(0),
+        first_(true),
         latitudes_(latitudes),
         longitudes_(longitudes) {}
 
-    ~IrregularLatlonIterator() { ASSERT(count_ == ni_ * nj_); }
+    ~IrregularLatlonIterator() override {
+        auto count = count_ + (i_ > 0 || j_ > 0 ? 1 : 0);
+        ASSERT(count == ni_ * nj_);
+    }
+
+    IrregularLatlonIterator(const IrregularLatlonIterator&)            = delete;
+    IrregularLatlonIterator(IrregularLatlonIterator&&)                 = delete;
+    IrregularLatlonIterator& operator=(const IrregularLatlonIterator&) = delete;
+    IrregularLatlonIterator& operator=(IrregularLatlonIterator&&)      = delete;
 };
 
 
@@ -224,22 +242,26 @@ bool IrregularLatlon::includesSouthPole() const {
 
 
 atlas::Grid IrregularLatlon::atlasGrid() const {
+#if mir_HAVE_ATLAS
+    ASSERT(numberOfPoints());
 
-    auto pts = new std::vector<atlas::PointXY>();
-    pts->reserve(latitudes_.size() * longitudes_.size());
+    std::vector<atlas::PointXY> pts;
+    pts.reserve(numberOfPoints());
 
     for (double lat : latitudes_) {
         for (double lon : longitudes_) {
-            pts->push_back(atlas::PointXY(lon, lat));
+            pts.emplace_back(lon, lat);
         }
     }
 
-    return atlas::UnstructuredGrid(pts);
+    return atlas::UnstructuredGrid(std::move(pts));
+#else
+    NOTIMP;
+#endif
 }
 
 
-static RepresentationBuilder<IrregularLatlon> irregularLatlon("irregular_latlon");
+static const RepresentationBuilder<IrregularLatlon> irregularLatlon("irregular_latlon");
 
 
-}  // namespace repres
-}  // namespace mir
+}  // namespace mir::repres::unsupported
